# pytonik

[![Build Status](https://img.shields.io/pypi/v/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Downloads](https://pepy.tech/badge/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Wheel](https://img.shields.io/pypi/wheel/pytonik.svg)](https://pypi.python.org/pypi/pytonik)
[![Python Version](https://img.shields.io/pypi/pyversions/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Donate](http://img.shields.io/liberapay/receives/pytonik.svg?logo=liberapay)](https://liberapay.com/pytonik/donate)
[![License](https://img.shields.io/pypi/l/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Gitter](https://badges.gitter.im/pytonik-mvc/community.svg)](https://gitter.im/pytonik-mvc/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)


<p align="center">
	<img  height="150" src="http://betacodings.com/public/pytonik_logo_color.png">
</p>


Pytonik is a python framework built to enhance web development fast and easy, also help web developers to build more apps with less codes. it uses expressive architectural pattern, structured on model view controller MVC  and bundles of component to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/pytonik)

## How to setup

if you are running a local machine you will need to install either, wamp, xampp, lamp or mamp. Enable CGI at httpd.conf file:


To Create Pytonik Project Folder 

```
$ pytonik-start
```

To Run Pytonik Server

```
$ pytonik-server
```

To Install Project Requirements  from ```requirements.txt``` file.

```
$ pytonik-install
```


To Read Pytonik Docs

```
$ pytonik-docs
```

## Contributing
For guidance on setting up a development environment and how to make a contribution to Pytonik, see the [contributing guidelines.](https://github.com/pytonik/pytonik/blob/master/CONTRIBUTING.md)


## Documentation on how to?

* [Getting Started](https://pytonik.readthedocs.io/en/1.9.8)

## Donate

Support Pytonik and the libraries it uses. In order to grow the community of contributors and users, and allow the maintainers to devote more time to the projects, [please donate today.](https://liberapay.com/pytonik/)


## Contact

**Name:**  Pytonik MVC

**Email:** dev@pytonik.com
